.. raw:: html

    <p align="center">
        <img width="75%" style="display: block;" src='docs/partial_source/logos/logo.png'>
    </p>

.. raw:: html

    <br/>
    <a href="https://pypi.org/project/ivy-demo-utils">
        <img style="float: left; padding-right: 4px; padding-bottom: 4px;" src="https://badge.fury.io/py/ivy-demo-utils.svg">
    </a>
    <a href="https://www.apache.org/licenses/LICENSE-2.0">
        <img style="float: left; padding-right: 4px; padding-bottom: 4px;" src="https://img.shields.io/pypi/l/ivy-demo-utils">
    </a>
    <a href="https://discord.gg/EN9YS3QW8w">
        <img style="float: left; padding-right: 4px; padding-bottom: 4px;" src="https://img.shields.io/discord/799879767196958751?color=blue&label=%20&logo=discord&logoColor=white">
    </a>
    <br clear="all" />

**A set of utilities for creating visual demos for Ivy libraries.**

|
| **Supported Frameworks:**

.. raw:: html

    <div style="display: block;">
        <img width="6.667%" style="float: left;" src="docs/partial_source/logos/supported/empty.png">
        <a href="https://jax.readthedocs.io">
            <img width="12%" style="float: left;" src="docs/partial_source/logos/supported/jax_logo.png">
        </a>
        <img width="6.667%" style="float: left;" src="docs/partial_source/logos/supported/empty.png">
        <a href="https://www.tensorflow.org">
            <img width="12%" style="float: left;" src="docs/partial_source/logos/supported/tensorflow_logo.png">
        </a>
        <img width="6.667%" style="float: left;" src="docs/partial_source/logos/supported/empty.png">
        <a href="https://pytorch.org">
            <img width="12%" style="float: left;" src="docs/partial_source/logos/supported/pytorch_logo.png">
        </a>
        <img width="6.667%" style="float: left;" src="docs/partial_source/logos/supported/empty.png">
        <a href="https://mxnet.apache.org">
            <img width="12%" style="float: left;" src="docs/partial_source/logos/supported/mxnet_logo.png">
        </a>
        <img width="6.667%" style="float: left;" src="docs/partial_source/logos/supported/empty.png">
        <a href="https://numpy.org">
            <img width="12%" style="float: left;" src="docs/partial_source/logos/supported/numpy_logo.png">
        </a>
        <img width="6.667%" style="float: left;" src="docs/partial_source/logos/supported/empty.png">
    </div>
